@@ -189,12 +189,16 @@ class SMTPConnection(object):
         if not email_message.recipients():
             return False
         try:
+            recipients = email_message.recipients()
             if settings.email.is_live:
                 self.connection.sendmail(email_message.from_email,
-                        email_message.recipients(),
+                        recipients,
                         email_message.message().as_string())
             else:
                 log.warn('email.is_live = False, email getting skipped')
+            log_recipients = ';'.join(recipients)
+            log_recipients = log_recipients if len(log_recipients) < 200 else log_recipients[0:200]
+            log.info('Email sent: "%s" to "%s"', email_message.subject, log_recipients)
         except:
             if not self.fail_silently:
                 raise
@@ -489,8 +493,11 @@ def _mail_admins(subject, message, format='text'):
     """used for testing"""
     email_class = get_email_class(format)
     fromaddr = settings.emails.from_server or settings.emails.from_default
+    recipients = settings.emails.admins
+    if not recipients:
+        log.warn('mail_admins() used but settings.emails.admins is empty')
     return email_class(settings.email.subject_prefix + subject, message,
-                 fromaddr, settings.emails.admins
+                 fromaddr, recipients
             )
 
 def mail_admins(subject, message, format='text', fail_silently=False):
@@ -502,8 +509,11 @@ def _mail_programmers(subject, message, format='text'):
     """used for testing"""
     email_class = get_email_class(format)
     fromaddr = settings.emails.from_server or settings.emails.from_default
+    recipients = settings.emails.programmers
+    if not recipients:
+        log.warn('mail_programmers() used but settings.emails.programmers is empty')
     return email_class(settings.email.subject_prefix + subject, message,
-               fromaddr , settings.emails.programmers
+               fromaddr , recipients
             )
 
 def mail_programmers(subject, message, format='text', fail_silently=False):
